#
# spec file for package ghc-hslua-core
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name hslua-core
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        2.3.2
Release:        1.3
Summary:        Bindings to Lua, an embeddable scripting language
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-exceptions-devel
BuildRequires:  ghc-exceptions-prof
BuildRequires:  ghc-lua-devel
BuildRequires:  ghc-lua-prof
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-mtl-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-lua-arbitrary-devel
BuildRequires:  ghc-lua-arbitrary-prof
BuildRequires:  ghc-quickcheck-instances-devel
BuildRequires:  ghc-quickcheck-instances-prof
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-hunit-prof
BuildRequires:  ghc-tasty-prof
BuildRequires:  ghc-tasty-quickcheck-devel
BuildRequires:  ghc-tasty-quickcheck-prof
%endif

%description
Wrappers and helpers to bridge Haskell and <https://www.lua.org/ Lua>.

It builds upon the /lua/ package, which allows to bundle a Lua interpreter with
a Haskell program.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Thu Jan 18 2024 Peter Simons <psimons@suse.com>
- Update hslua-core to version 2.3.2.
  [#]# hslua-core-2.3.2
  Released 2024-01-18.
  - Relaxed upper bound for text, and bytestring, allowing
    text-2.1, and bytestring-0.12.
* Thu Apr 13 2023 Peter Simons <psimons@suse.com>
- Update hslua-core to version 2.3.1.
  [#]# hslua-core-2.3.1
  Released 2023-03-17.
  - New module *HsLua.Core.Debug*: the module provides bindings to
    a subset of functions of the Lua debug interface. Currently
    the module only exports `getupvalue` and `setupvalue`, both of
    which are also re-exported from *HsLua.Core*.
  [#]# hslua-core-2.3.0
  Released 2023-03-13.
  - The functions `loadfile`, `dofile`, and `dofileTrace` now
    expect the argument to be of type `Maybe FilePath`. The
    functions load from *stdin* when the argument is `Nothing`.
  - Added `setwarnf'` for simple warning messgae handling: The
    built-in method of setting a warn function is flexible but not
    straight-forward to use. The new `setwarnf'` function allows
    to set a Haskell action as a warning hook: the default warning
    behavior is kept in place, but, in addition to the default
    action, the hook is called on the concatenated warning
    messages. This can be used to plug Lua warnings into an
    application specific Haskell reporting system.
  - Export `GCManagedState`, `newGCManagedState`,
    `closeGCManagedState`, and `withGCManagedState` from
    `HsLua.Core`.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sun Jun 19 2022 Peter Simons <psimons@suse.com>
- Update hslua-core to version 2.2.1.
  [#]# hslua-core-2.2.1
  Released 2022-06-19.
  - Ensure that loadfile works with umlauts in filepath: The OS
    does not necessarily expect filenames to be UTF-8 encoded,
    especially Windows. On non-Windows systems, the current file
    system encoding is now used to convert filenames to C
    strings. On Windows, the `CP_ACP` codepage is used, as
    required by the Windows API.
  - GC managed Lua state: Add new type `GCManagedState` and
    functions `newGCManagedState`, `closeGCManagedState`, and
    `withGCManagedState`. These allow to create and use a Lua
    state in flexible ways in that it does not require the state
    to be closed explicitly. The state will be closed when the
    respective variable is collected.
  - Require lua-2.2.1.
  - Relax upper bound for mtl, allow mtl-2.3.
* Sat Feb 19 2022 Peter Simons <psimons@suse.com>
- Update hslua-core to version 2.2.0.
  [#]# hslua-core-2.2.0
  Released 2022-02-19.
  - Use lua-2.2.0, which requires Lua 5.4.
  - Rename `newuserdata` to `newuserdatauv` and let it take the
    number of associated uservalues as an additional argument.
    Similarly, `newhsuserdata` is now `newhsuserdatauv`.
  - Rename `getuservalue` and `setuservalue` to `getiuservalue`
    and `setiuservalue`, respectively. Like both functions now
    take an extra argument specifying the number of the uservalue
    that should be retrieved or set.
    It is now possible for `setiuservalue` to fail, so it returns
    a boolean to indicate whether the action was successful.
  - The `GCControl` type has been updated to match the new gc
    control:
  - The GCStep constructor takes an argument "stepsize";
  - constructors GCGen and GCInc have been added;
  - constructors GCSetPause and GCSetStepMul have been removed.
* Sat Jan 29 2022 Peter Simons <psimons@suse.com>
- Update hslua-core to version 2.1.0.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/hslua-core-2.1.0/src/CHANGELOG.md
* Thu Nov  4 2021 psimons@suse.com
- Update hslua-core to version 2.0.0.2.
  [#]# hslua-core 2.0.0.2
  Released 2021-11-03.
  - Fixed output of `pushTypeMismatchError` when there is no value
    at the given index. Previously the function would report the
    value as type `string` and now reports it as `no value`.
* Mon Nov  1 2021 psimons@suse.com
- Add hslua-core at version 2.0.0.1.
